@@ -2,7 +2,7 @@
 #
 # This file is part of Nominatim. (https://nominatim.org)
 #
-# Copyright (C) 2024 by the Nominatim developer community.
+# Copyright (C) 2025 by the Nominatim developer community.
 # For a full list of authors see the git log.
 """
 Generic part of the server implementation of the v1 API.
@@ -156,17 +156,16 @@ async def details_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
 
     debug = setup_debugging(params)
 
-    locales = Locales.from_accept_languages(get_accepted_languages(params))
-
     result = await api.details(place,
                                address_details=params.get_bool('addressdetails', False),
+                               entrances=params.get_bool('entrances', False),
                                linked_places=params.get_bool('linkedplaces', True),
                                parented_places=params.get_bool('hierarchy', False),
                                keywords=params.get_bool('keywords', False),
                                geometry_output=(GeometryFormat.GEOJSON
                                                 if params.get_bool('polygon_geojson', False)
                                                 else GeometryFormat.NONE),
-                               locales=locales
+                               query_stats=params.query_stats()
                                )
 
     if debug:
@@ -175,11 +174,16 @@ async def details_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     if result is None:
         params.raise_error('No place with that OSM ID found.', status=404)
 
+    locales = Locales.from_accept_languages(get_accepted_languages(params))
+    locales.localize_results([result])
+
     output = params.formatting().format_result(
         result, fmt,
         {'locales': locales,
          'group_hierarchy': params.get_bool('group_hierarchy', False),
-         'icon_base_url': params.config().MAPICON_URL})
+         'icon_base_url': params.config().MAPICON_URL,
+         'entrances': params.get_bool('entrances', False),
+         })
 
     return build_response(params, output, num_results=1)
 
@@ -194,7 +198,7 @@ async def reverse_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     details = parse_geometry_details(params, fmt)
     details['max_rank'] = helpers.zoom_to_rank(params.get_int('zoom', 18))
     details['layers'] = get_layers(params)
-    details['locales'] = Locales.from_accept_languages(get_accepted_languages(params))
+    details['query_stats'] = params.query_stats()
 
     result = await api.reverse(coord, **details)
 
@@ -210,9 +214,14 @@ async def reverse_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     else:
         query = ''
 
+    if result:
+        Locales.from_accept_languages(get_accepted_languages(params)).localize_results(
+            [result])
+
     fmt_options = {'query': query,
                    'extratags': params.get_bool('extratags', False),
                    'namedetails': params.get_bool('namedetails', False),
+                   'entrances': params.get_bool('entrances', False),
                    'addressdetails': params.get_bool('addressdetails', True)}
 
     output = params.formatting().format_result(ReverseResults([result] if result else []),
@@ -227,7 +236,7 @@ async def lookup_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     fmt = parse_format(params, SearchResults, 'xml')
     debug = setup_debugging(params)
     details = parse_geometry_details(params, fmt)
-    details['locales'] = Locales.from_accept_languages(get_accepted_languages(params))
+    details['query_stats'] = params.query_stats()
 
     places = []
     for oid in (params.get('osm_ids') or '').split(','):
@@ -246,8 +255,11 @@ async def lookup_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     if debug:
         return build_response(params, loglib.get_and_disable(), num_results=len(results))
 
+    Locales.from_accept_languages(get_accepted_languages(params)).localize_results(results)
+
     fmt_options = {'extratags': params.get_bool('extratags', False),
                    'namedetails': params.get_bool('namedetails', False),
+                   'entrances': params.get_bool('entrances', False),
                    'addressdetails': params.get_bool('addressdetails', True)}
 
     output = params.formatting().format_result(results, fmt, fmt_options)
@@ -293,7 +305,9 @@ async def search_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     debug = setup_debugging(params)
     details = parse_geometry_details(params, fmt)
 
+    details['query_stats'] = params.query_stats()
     details['countries'] = params.get('countrycodes', None)
+    details['entrances'] = params.get_bool('entrances', False)
     details['excluded'] = params.get('exclude_place_ids', None)
     details['viewbox'] = params.get('viewbox', None) or params.get('viewboxlbrt', None)
     details['bounded_viewbox'] = params.get_bool('bounded', False)
@@ -310,8 +324,6 @@ async def search_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     else:
         details['layers'] = get_layers(params)
 
-    details['locales'] = Locales.from_accept_languages(get_accepted_languages(params))
-
     # unstructured query parameters
     query = params.get('q', None)
     # structured query parameters
@@ -336,6 +348,8 @@ async def search_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
     except UsageError as err:
         params.raise_error(str(err))
 
+    Locales.from_accept_languages(get_accepted_languages(params)).localize_results(results)
+
     if details['dedupe'] and len(results) > 1:
         results = helpers.deduplicate_results(results, max_results)
 
@@ -359,6 +373,7 @@ async def search_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any:
                    'viewbox': queryparts.get('viewbox'),
                    'extratags': params.get_bool('extratags', False),
                    'namedetails': params.get_bool('namedetails', False),
+                   'entrances': params.get_bool('entrances', False),
                    'addressdetails': params.get_bool('addressdetails', False)}
 
     output = params.formatting().format_result(results, fmt, fmt_options)
@@ -374,14 +389,17 @@ async def deletable_endpoint(api: NominatimAPIAsync, params: ASGIAdaptor) -> Any
     """
     fmt = parse_format(params, RawDataList, 'json')
 
+    results = RawDataList()
     async with api.begin() as conn:
-        sql = sa.text(""" SELECT p.place_id, country_code,
-                                 name->'name' as name, i.*
-                          FROM placex p, import_polygon_delete i
-                          WHERE p.osm_id = i.osm_id AND p.osm_type = i.osm_type
-                                AND p.class = i.class AND p.type = i.type
-                      """)
-        results = RawDataList(r._asdict() for r in await conn.execute(sql))
+        for osm_type in ('N', 'W', 'R'):
+            sql = sa.text(""" SELECT p.place_id, country_code,
+                                     name->'name' as name, i.*
+                              FROM placex p, import_polygon_delete i
+                              WHERE i.osm_type = :osm_type
+                                    AND p.osm_id = i.osm_id AND p.osm_type = :osm_type
+                                    AND p.class = i.class AND p.type = i.type
+                          """)
+            results.extend(r._asdict() for r in await conn.execute(sql, {'osm_type': osm_type}))
 
     return build_response(params, params.formatting().format_result(results, fmt, {}))
 
